# Copyright © 2015, 2021 Nick Bowler
# License GPLv3+: GNU General Public License version 3 or any later version.
# This is free software: you are free to change and redistribute it.
# There is NO WARRANTY, to the extent permitted by law.

EAPI=7

DESCRIPTION="English-language fork of ONScripter: a free clone of NScripter"
HOMEPAGE="http://unclemion.com/dev/projects/onscripter-en"

# This package has a hard dep on SDL_ttf-2.0.10, fonts do not work with
# 2.0.11.  Download that release specifically.
SRC_URI="https://web.archive.org/web/20150801182531/http://unclemion.com/dev/attachments/download/36/$P-src.tar.bz2
	https://www.libsdl.org/projects/SDL_ttf/release/SDL_ttf-2.0.10.tar.gz
	"

LICENSE="GPL-2+ ZLIB"
SLOT="0"
KEYWORDS="~amd64"

BDEPEND="app-arch/bzip2
	virtual/pkgconfig"
DEPEND="media-libs/libsdl
	media-libs/sdl-mixer[vorbis]
	media-libs/sdl-image
	media-libs/smpeg
	media-libs/freetype:2
	x11-libs/libXt"
RDEPEND=$DEPEND

PATCHES=(
	"$FILESDIR/$P-fix-configure.patch"
	"$FILESDIR/$PN-respect-CXXFLAGS.patch"
)

src_configure() {
	local pkgconfig=`command -v pkg-config`

	einfo "Configuring SDL_ttf $pkgconfig"
	cd "$WORKDIR/SDL_ttf-2.0.10" || die
	econf --prefix="$S/onscrlib" --libdir='${prefix}/lib' \
		--enable-static --disable-shared \
		FREETYPE_CONFIG="$pkgconfig freetype2"

	einfo "Configuring $PN"
	cd "$S" || die
	econf --unsupported-compiler \
		--onscrlib-path="$S" --with-internal-sdl-ttf
}

src_compile() {
	einfo "Building SDL_ttf"
	cd "$WORKDIR/SDL_ttf-2.0.10" || die
	emake noinst_PROGRAMS= install

	einfo "Building $PN"
	cd "$S" || die
	default
}

src_install() {
	dodoc README
	dobin onscripter-en
}
